==> suse-11.1-x86.tar.gz: usr/share/YaST2/modules/LibStorage/VolumeInfo.pm <==
package LibStorage::VolumeInfo;
BEGIN {
    %TYPEINFO = (
        ALL_METHODS => 0,
        new => ["function", "any", "string"],
        swig_sizeK_get => ["function", "integer", "any"],
        swig_sizeK_set => ["function", "void", "any", "integer"],
        swig_major_get => ["function", "integer", "any"],
        swig_major_set => ["function", "void", "any", "integer"],
        swig_minor_get => ["function", "integer", "any"],
        swig_minor_set => ["function", "void", "any", "integer"],
        swig_name_get => ["function", "string", "any"],
        swig_name_set => ["function", "void", "any", "string"],
        swig_device_get => ["function", "string", "any"],
        swig_device_set => ["function", "void", "any", "string"],
        swig_mount_get => ["function", "string", "any"],
        swig_mount_set => ["function", "void", "any", "string"],
        swig_mount_by_get => ["function", "integer", "any"],
        swig_mount_by_set => ["function", "void", "any", "integer"],
        swig_usedByType_get => ["function", "integer", "any"],
        swig_usedByType_set => ["function", "void", "any", "integer"],
        swig_usedByName_get => ["function", "string", "any"],
        swig_usedByName_set => ["function", "void", "any", "string"],
        swig_usedByDevice_get => ["function", "string", "any"],
        swig_usedByDevice_set => ["function", "void", "any", "string"],
        swig_fstab_options_get => ["function", "string", "any"],
        swig_fstab_options_set => ["function", "void", "any", "string"],
        swig_uuid_get => ["function", "string", "any"],
        swig_uuid_set => ["function", "void", "any", "string"],
        swig_label_get => ["function", "string", "any"],
        swig_label_set => ["function", "void", "any", "string"],
        swig_mkfs_options_get => ["function", "string", "any"],
        swig_mkfs_options_set => ["function", "void", "any", "string"],
        swig_tunefs_options_get => ["function", "string", "any"],
        swig_tunefs_options_set => ["function", "void", "any", "string"],
        swig_loop_get => ["function", "string", "any"],
        swig_loop_set => ["function", "void", "any", "string"],
        swig_dtxt_get => ["function", "string", "any"],
        swig_dtxt_set => ["function", "void", "any", "string"],
        swig_encryption_get => ["function", "integer", "any"],
        swig_encryption_set => ["function", "void", "any", "integer"],
        swig_crypt_pwd_get => ["function", "string", "any"],
        swig_crypt_pwd_set => ["function", "void", "any", "string"],
        swig_fs_get => ["function", "integer", "any"],
        swig_fs_set => ["function", "void", "any", "integer"],
        swig_format_get => ["function", "boolean", "any"],
        swig_format_set => ["function", "void", "any", "boolean"],
        swig_create_get => ["function", "boolean", "any"],
        swig_create_set => ["function", "void", "any", "boolean"],
        swig_is_mounted_get => ["function", "boolean", "any"],
        swig_is_mounted_set => ["function", "void", "any", "boolean"],
        swig_resize_get => ["function", "boolean", "any"],
        swig_resize_set => ["function", "void", "any", "boolean"],
        swig_ignore_fs_get => ["function", "boolean", "any"],
        swig_ignore_fs_set => ["function", "void", "any", "boolean"],
        swig_OrigSizeK_get => ["function", "integer", "any"],
        swig_OrigSizeK_set => ["function", "void", "any", "integer"],
    );
}

1;

==> suse-11.2-x86.tar.gz: usr/share/YaST2/modules/LibStorage/VolumeInfo.pm <==
package LibStorage::VolumeInfo;
BEGIN {
    %TYPEINFO = (
        ALL_METHODS => 0,
        new => ["function", "any", "string"],
        swig_sizeK_get => ["function", "integer", "any"],
        swig_sizeK_set => ["function", "void", "any", "integer"],
        swig_major_get => ["function", "integer", "any"],
        swig_major_set => ["function", "void", "any", "integer"],
        swig_minor_get => ["function", "integer", "any"],
        swig_minor_set => ["function", "void", "any", "integer"],
        swig_name_get => ["function", "string", "any"],
        swig_name_set => ["function", "void", "any", "string"],
        swig_device_get => ["function", "string", "any"],
        swig_device_set => ["function", "void", "any", "string"],
        swig_mount_get => ["function", "string", "any"],
        swig_mount_set => ["function", "void", "any", "string"],
        swig_mount_by_get => ["function", "integer", "any"],
        swig_mount_by_set => ["function", "void", "any", "integer"],
        swig_usedByType_get => ["function", "integer", "any"],
        swig_usedByType_set => ["function", "void", "any", "integer"],
        swig_usedByDevice_get => ["function", "string", "any"],
        swig_usedByDevice_set => ["function", "void", "any", "string"],
        swig_ignore_fstab_get => ["function", "boolean", "any"],
        swig_ignore_fstab_set => ["function", "void", "any", "boolean"],
        swig_fstab_options_get => ["function", "string", "any"],
        swig_fstab_options_set => ["function", "void", "any", "string"],
        swig_uuid_get => ["function", "string", "any"],
        swig_uuid_set => ["function", "void", "any", "string"],
        swig_label_get => ["function", "string", "any"],
        swig_label_set => ["function", "void", "any", "string"],
        swig_mkfs_options_get => ["function", "string", "any"],
        swig_mkfs_options_set => ["function", "void", "any", "string"],
        swig_tunefs_options_get => ["function", "string", "any"],
        swig_tunefs_options_set => ["function", "void", "any", "string"],
        swig_loop_get => ["function", "string", "any"],
        swig_loop_set => ["function", "void", "any", "string"],
        swig_dtxt_get => ["function", "string", "any"],
        swig_dtxt_set => ["function", "void", "any", "string"],
        swig_encryption_get => ["function", "integer", "any"],
        swig_encryption_set => ["function", "void", "any", "integer"],
        swig_crypt_pwd_get => ["function", "string", "any"],
        swig_crypt_pwd_set => ["function", "void", "any", "string"],
        swig_fs_get => ["function", "integer", "any"],
        swig_fs_set => ["function", "void", "any", "integer"],
        swig_format_get => ["function", "boolean", "any"],
        swig_format_set => ["function", "void", "any", "boolean"],
        swig_create_get => ["function", "boolean", "any"],
        swig_create_set => ["function", "void", "any", "boolean"],
        swig_is_mounted_get => ["function", "boolean", "any"],
        swig_is_mounted_set => ["function", "void", "any", "boolean"],
        swig_resize_get => ["function", "boolean", "any"],
        swig_resize_set => ["function", "void", "any", "boolean"],
        swig_ignore_fs_get => ["function", "boolean", "any"],
        swig_ignore_fs_set => ["function", "void", "any", "boolean"],
        swig_origSizeK_get => ["function", "integer", "any"],
        swig_origSizeK_set => ["function", "void", "any", "integer"],
    );
}

1;
